import pytest

from django.core.management.base import CommandError

from hobo.environment.models import ServiceBase
from hobo.environment.management.commands.cook import Command


def test_check_action(monkeypatch):
    """no exception raised if url are available"""
    command = Command()
    command.server_action = 'mock a server_action handler (ex: hobo-create)'
    action, action_args = 'server-action', {u'url': u'https://test.org/'}

    monkeypatch.setattr(ServiceBase, 'is_resolvable', lambda x: True)
    monkeypatch.setattr(ServiceBase, 'has_valid_certificate', lambda x: True)
    command.check_action(action, action_args)
    assert True

def test_check_action_unknown_action(monkeypatch):
    """raise CommandError"""
    command = Command()
    command.server_action = 'mock a server_action handler (ex: hobo-create)'
    action, action_args = 'not-a-server-action', {u'url': u'https://test.org/'}

    monkeypatch.setattr(ServiceBase, 'is_resolvable', lambda x: True)
    monkeypatch.setattr(ServiceBase, 'has_valid_certificate', lambda x: True)
    with pytest.raises(CommandError) as e_info:
        command.check_action(action, action_args)
    assert 'Unknown action not-a-server-action' in str(e_info.value)

def test_check_action_unresolvable(monkeypatch):
    """raise CommandError"""
    command = Command()
    command.server_action = 'mock a server_action handler (ex: hobo-create)'
    action, action_args = 'server-action', {u'url': u'https://test.org/'}

    monkeypatch.setattr(ServiceBase, 'is_resolvable', lambda x: False)
    monkeypatch.setattr(ServiceBase, 'has_valid_certificate', lambda x: True)
    with pytest.raises(CommandError) as e_info:
        command.check_action(action, action_args)
    assert 'is not resolvable' in str(e_info.value)

def test_check_action_invalid_certificat(monkeypatch):
    """raise CommandError"""
    command = Command()
    command.server_action = 'mock a server_action handler (ex: hobo-create)'
    action, action_args = 'server-action', {u'url': u'https://test.org/'}

    monkeypatch.setattr(ServiceBase, 'is_resolvable', lambda x: True)
    monkeypatch.setattr(ServiceBase, 'has_valid_certificate', lambda x: False)
    with pytest.raises(CommandError) as e_info:
        command.check_action(action, action_args)
    assert 'has no valid certificate' in str(e_info.value)
